@@ -101,14 +101,51 @@ void static inline initialMiScan(struct ht **hta,int n,int m,int *y,int ny,int *
 
 SEXP makeAns(int k,double **score,int **idx){
  SEXP Ans; PROTECT(Ans=allocVector(VECSXP,2));
+ SEXP AnsN; PROTECT(AnsN=allocVector(STRSXP,2));
  SEXP Idx; PROTECT(Idx=allocVector(INTSXP,k));
  SEXP Score; PROTECT(Score=allocVector(REALSXP,k));
+
+ SET_STRING_ELT(AnsN,0,mkChar("selection"));
+ SET_STRING_ELT(AnsN,1,mkChar("score"));
+ setAttrib(Ans,R_NamesSymbol,AnsN);
+ 
  SET_VECTOR_ELT(Ans,0,Idx);
  SET_VECTOR_ELT(Ans,1,Score);
 
  if(score) *score=REAL(Score);
  if(idx) *idx=INTEGER(Idx);
- UNPROTECT(3);
+ UNPROTECT(4);
+ return(Ans);
+}
+
+SEXP finishAns(int k,SEXP Ans,SEXP X){
+ if(k<length(VECTOR_ELT(Ans,0))){
+  //Need to clip Ans
+  SEXP Iidx; PROTECT(Iidx=allocVector(INTSXP,k));
+  SEXP Sscore; PROTECT(Sscore=allocVector(REALSXP,k));
+  int *idx=INTEGER(VECTOR_ELT(Ans,0)),*iidx=INTEGER(Iidx);
+  double *score=REAL(VECTOR_ELT(Ans,1)),*sscore=REAL(Sscore);
+  for(int e=0;e<k;e++){
+   sscore[e]=score[e];
+   iidx[e]=idx[e];
+  }
+  SET_VECTOR_ELT(Ans,0,Iidx);
+  SET_VECTOR_ELT(Ans,1,Sscore);
+  UNPROTECT(2);
+ }
+ //X is a data.frame, does it have names?
+ SEXP Xn=getAttrib(X,R_NamesSymbol);
+ if(!isNull(Xn)){
+  //Copy names into names of scores and selection
+  SEXP An; PROTECT(An=allocVector(STRSXP,k));
+  int *idx=INTEGER(VECTOR_ELT(Ans,0));
+  for(int e=0;e<k;e++){
+   SET_STRING_ELT(An,e,STRING_ELT(Xn,idx[e]-1));
+  }
+  setAttrib(VECTOR_ELT(Ans,0),R_NamesSymbol,An);
+  setAttrib(VECTOR_ELT(Ans,1),R_NamesSymbol,An);
+  UNPROTECT(1);
+ }
  return(Ans);
 }
 
