@@ -10,8 +10,8 @@ for(algo in c("MIM","JMIM","NJMIM","JMI","DISR","CMIM","MRMR")){
  test_that(sprintf("Native %s works like pure %s",algo,algo),{
   do.call(sprintf("pure%s",algo),input)->pure
   do.call(algo,input)->native
-  expect_equal(pure$scores,native$scores)
-  expect_equal(pure$selection,native$selection)
+  expect_equal(pure$score,setNames(native$score,NULL))
+  expect_equal(pure$selection,names(native$selection))
  })
 }
 
